import { HttpMethod } from "../http/HttpMethod";
import { StateMachineTransition } from "../common/StateMachineTransition";
import { AbstractModel } from "./AbstractModel";
import { Constructor } from "../common/types";
export declare const Model: (config?: {
    /**
     * Description about this model.
     */
    description?: string | undefined;
    /**
     * Override a model by using it id so that any service that uses the old model will use this model instead.
     * To support backward compatible, this new model should extends from the old model.
     */
    override?: (new () => AbstractModel) | undefined;
    /**
     * Ignore some http method to prevent auto generation of routes and/or endpoints
     */
    ignoreCrud?: HttpMethod[] | undefined;
} | undefined) => <T extends Constructor<AbstractModel>>(constructor: T) => T;
export declare const PK: (config?: {
    autoIncrement?: boolean | undefined;
} | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const CurrentUser: () => (prototype: AbstractModel, propertyKey: string) => void;
export declare const FK: (config: {
    model?: Constructor<AbstractModel>;
    cascade?: boolean;
}) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const HasMany: <T extends AbstractModel>(config: {
    model: Constructor<T>;
    field: keyof T;
}) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const Indexing: (config?: {
    group?: string | undefined;
} | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const Unique: (name?: string | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const Default: (value: any) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const StateMachine: <T>(config: {
    transition: StateMachineTransition<T>[];
}) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const Searchable: (config?: {
    caseSensitive?: boolean | undefined;
    accentSensitive?: boolean | undefined;
} | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const ServerTime: () => (prototype: AbstractModel, propertyKey: string) => void;
export declare const ServerModify: <T>(config?: {
    fn?: ((value: T) => T) | undefined;
} | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const Label: () => (prototype: AbstractModel, propertyKey: string) => void;
